/**
 * Application Performance Monitoring (APM) Control Plane API
 * Provide a set of APIs for tenant to perform operations like create, update, delete and list APM domains, and also
work request APIs to monitor progress of these operations.

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { ApmDomainWaiter } from "./apmdomain-waiter";
export declare enum ApmDomainApiKeys {
}
export declare class ApmDomainClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ApmDomainWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ApmDomainWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ApmDomainWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ApmDomainWaiter;
    /**
     * Moves a APM Domain into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * @param ChangeApmDomainCompartmentRequest
     * @return ChangeApmDomainCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/ChangeApmDomainCompartment.ts.html |here} to see how to use ChangeApmDomainCompartment API.
     */
    changeApmDomainCompartment(changeApmDomainCompartmentRequest: requests.ChangeApmDomainCompartmentRequest): Promise<responses.ChangeApmDomainCompartmentResponse>;
    /**
     * Creates a new APM Domain.
     *
     * @param CreateApmDomainRequest
     * @return CreateApmDomainResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/CreateApmDomain.ts.html |here} to see how to use CreateApmDomain API.
     */
    createApmDomain(createApmDomainRequest: requests.CreateApmDomainRequest): Promise<responses.CreateApmDomainResponse>;
    /**
     * Delete the specified APM domain asynchronously. The APM domain is placed in the 'Deleting' state and will stop
     * accepting any operation requests. All resources associated with the APM domain are eventually recovered. Use the
     * returned work request to track the progress of the background activity to complete deleting the domain.
     *
     * @param DeleteApmDomainRequest
     * @return DeleteApmDomainResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/DeleteApmDomain.ts.html |here} to see how to use DeleteApmDomain API.
     */
    deleteApmDomain(deleteApmDomainRequest: requests.DeleteApmDomainRequest): Promise<responses.DeleteApmDomainResponse>;
    /**
     * Generates a set of new Data Keys for the specified APM domain with the specified names and
     * types. These will be added to the existing set of Data Keys for the specified APM domain.
     *
     * @param GenerateDataKeysRequest
     * @return GenerateDataKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/GenerateDataKeys.ts.html |here} to see how to use GenerateDataKeys API.
     */
    generateDataKeys(generateDataKeysRequest: requests.GenerateDataKeysRequest): Promise<responses.GenerateDataKeysResponse>;
    /**
     * Gets details of APM Domain by identifier
     * @param GetApmDomainRequest
     * @return GetApmDomainResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/GetApmDomain.ts.html |here} to see how to use GetApmDomain API.
     */
    getApmDomain(getApmDomainRequest: requests.GetApmDomainRequest): Promise<responses.GetApmDomainResponse>;
    /**
     * Gets the details of the work request with the given ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a (paginated) list of work requests related to a specific APM Domain.
     *
     * @param ListApmDomainWorkRequestsRequest
     * @return ListApmDomainWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/ListApmDomainWorkRequests.ts.html |here} to see how to use ListApmDomainWorkRequests API.
     */
    listApmDomainWorkRequests(listApmDomainWorkRequestsRequest: requests.ListApmDomainWorkRequestsRequest): Promise<responses.ListApmDomainWorkRequestsResponse>;
    /**
     * Lists all APM Domains for the specified tenant compartment.
     *
     * @param ListApmDomainsRequest
     * @return ListApmDomainsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/ListApmDomains.ts.html |here} to see how to use ListApmDomains API.
     */
    listApmDomains(listApmDomainsRequest: requests.ListApmDomainsRequest): Promise<responses.ListApmDomainsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ApmDomainSummary objects
     * contained in responses from the listApmDomains operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllApmDomains(request: requests.ListApmDomainsRequest): AsyncIterableIterator<model.ApmDomainSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listApmDomains operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllApmDomainsResponses(request: requests.ListApmDomainsRequest): AsyncIterableIterator<responses.ListApmDomainsResponse>;
    /**
     * Lists all Data Keys for the specified APM Domain. The caller may filter the list by specifying the 'dataKeyType'
     * query parameter.
     *
     * @param ListDataKeysRequest
     * @return ListDataKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/ListDataKeys.ts.html |here} to see how to use ListDataKeys API.
     */
    listDataKeys(listDataKeysRequest: requests.ListDataKeysRequest): Promise<responses.ListDataKeysResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Returns a (paginated) list of work requests in a given compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequest objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequest>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Removes the set of specified Data Keys from the specified APM domain. Agents would no longer
     * be able to use these data keys to upload to the APM domain once this operation is completed.
     *
     * @param RemoveDataKeysRequest
     * @return RemoveDataKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/RemoveDataKeys.ts.html |here} to see how to use RemoveDataKeys API.
     */
    removeDataKeys(removeDataKeysRequest: requests.RemoveDataKeysRequest): Promise<responses.RemoveDataKeysResponse>;
    /**
     * Update the APM domain when it is ready and active.
     * @param UpdateApmDomainRequest
     * @return UpdateApmDomainResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.3.1/apmcontrolplane/UpdateApmDomain.ts.html |here} to see how to use UpdateApmDomain API.
     */
    updateApmDomain(updateApmDomainRequest: requests.UpdateApmDomainRequest): Promise<responses.UpdateApmDomainResponse>;
}
